==> paper_uploads-0.8.3-py2.py3-none-any.whl: paper_uploads/models/__init__.py <==
"""
Class hierarchy:

┌────────────────┐
│  ResourceBase  │
└┬───────────────┘
 │
┌▼───────────┐
│  Resource  │
└┬───────────┘
 │
┌▼───────────────┐
│  FileResource  │
└┬───────────────┘
 │
 │   ┌─────────────────────┐
 ├───►  FileFieldResource  │
 │   └┬────────────────────┘
 │    │
 │    │    ┌────────────────────┐   ┌────────────────┐
 │    ├────►  UploadedFileBase  ├───►  UploadedFile  │
 │    │    └────────────────────┘   └────────────────┘
 │    │
 │    │    ┌─────────────────────┐   ┌─────────────────┐
 │    ├────►  UploadedImageBase  ├───►  UploadedImage  │
 │    │    └─────────────────────┘   └─────────────────┘
 │    │
 │    │    ┌──────────────────────────┐
 │    └────►  CollectionFileItemBase  │
 │         └┬─────────────────────────┘
 │          │
 │          │   ┌────────────────┐    ┌────────────┐
 │          ├───►  FileItemBase  ├───►  FileItem   │
 │          │   └────────────────┘    └────────────┘
 │          │
 │          │   ┌───────────────┐    ┌───────────┐
 │          ├───►  SVGItemBase  ├───►  SVGItem   │
 │          │   └───────────────┘    └───────────┘
 │          │
 │          │   ┌─────────────────┐    ┌─────────────┐
 │          └───►  ImageItemBase  ├───►  ImageItem   │
 │             └──────────────────┘    └─────────────┘
 │
 │    ┌──────────────────┐
 ├────►  CloudinaryFile  │
 │    └──────────────────┘
 │
 │    ┌───────────────────┐
 ├────►  CloudinaryImage  │
 │    └───────────────────┘
 │
 │    ┌───────────────────┐
 ├────►  CloudinaryMedia  │
 │    └───────────────────┘
 │
 │    ┌────────────────────────────────────┐
 └────►  CollectionCloudinaryFileItemBase  │
      └┬───────────────────────────────────┘
       │
       │   ┌──────────────────────────┐   ┌──────────────────────┐
       ├───►  CloudinaryFileItemBase  ├───►  CloudinaryFileItem  │
       │   └──────────────────────────┘   └──────────────────────┘
       │
       │   ┌───────────────────────────┐   ┌───────────────────────┐
       ├───►  CloudinaryImageItemBase  ├───►  CloudinaryImageItem  │
       │   └───────────────────────────┘   └───────────────────────┘
       │
       │   ┌───────────────────────────┐   ┌───────────────────────┐
       └───►  CloudinaryMediaItemBase  ├───►  CloudinaryMediaItem  │
           └───────────────────────────┘   └───────────────────────┘
"""

from .collection import (
    Collection,
    CollectionItemBase,
    ImageCollection,
    FileItemBase,
    ImageItemBase,
    SVGItemBase,
    FileItem,
    ImageItem,
    SVGItem,
)
from .fields import CollectionField, CollectionItem, FileField, ImageField
from .file import UploadedFileBase, UploadedFile
from .image import UploadedImageBase, UploadedImage

__all__ = [
    "UploadedFileBase",
    "UploadedFile",
    "UploadedImageBase",
    "UploadedImage",
    "FileField",
    "ImageField",
    "CollectionField",
    "CollectionItemBase",
    "CollectionItem",
    "Collection",
    "ImageCollection",
    "FileItemBase",
    "SVGItemBase",
    "ImageItemBase",
    "FileItem",
    "SVGItem",
    "ImageItem",
]

==> paper_uploads-0.9.3-py2.py3-none-any.whl: paper_uploads/models/__init__.py <==
"""
Class hierarchy:

┌────────────────┐
│  ResourceBase  │
└┬───────────────┘
 │
┌▼───────────┐
│  Resource  │
└┬───────────┘
 │
┌▼───────────────┐
│  FileResource  │
└┬───────────────┘
 │
 │   ┌─────────────────────┐
 ├───►  FileFieldResource  │
 │   └┬────────────────────┘
 │    │
 │    │    ┌────────────────────┐   ┌────────────────┐
 │    ├────►  UploadedFileBase  ├───►  UploadedFile  │
 │    │    └────────────────────┘   └────────────────┘
 │    │
 │    │    ┌───────────────────────┐   ┌───────────────────┐
 │    ├────►  UploadedSVGFileBase  ├───►  UploadedSVGFile  │
 │    │    └───────────────────────┘   └───────────────────┘
 │    │
 │    │    ┌─────────────────────┐   ┌─────────────────┐
 │    ├────►  UploadedImageBase  ├───►  UploadedImage  │
 │    │    └─────────────────────┘   └─────────────────┘
 │    │
 │    │    ┌──────────────────────────┐
 │    └────►  CollectionFileItemBase  │
 │         └┬─────────────────────────┘
 │          │
 │          │   ┌────────────────┐    ┌────────────┐
 │          ├───►  FileItemBase  ├───►  FileItem   │
 │          │   └────────────────┘    └────────────┘
 │          │
 │          │   ┌───────────────┐    ┌───────────┐
 │          ├───►  SVGItemBase  ├───►  SVGItem   │
 │          │   └───────────────┘    └───────────┘
 │          │
 │          │   ┌─────────────────┐    ┌─────────────┐
 │          └───►  ImageItemBase  ├───►  ImageItem   │
 │             └──────────────────┘    └─────────────┘
 │
 │    ┌──────────────────┐
 ├────►  CloudinaryFile  │
 │    └──────────────────┘
 │
 │    ┌───────────────────┐
 ├────►  CloudinaryImage  │
 │    └───────────────────┘
 │
 │    ┌───────────────────┐
 ├────►  CloudinaryMedia  │
 │    └───────────────────┘
 │
 │    ┌────────────────────────────────────┐
 └────►  CollectionCloudinaryFileItemBase  │
      └┬───────────────────────────────────┘
       │
       │   ┌──────────────────────────┐   ┌──────────────────────┐
       ├───►  CloudinaryFileItemBase  ├───►  CloudinaryFileItem  │
       │   └──────────────────────────┘   └──────────────────────┘
       │
       │   ┌───────────────────────────┐   ┌───────────────────────┐
       ├───►  CloudinaryImageItemBase  ├───►  CloudinaryImageItem  │
       │   └───────────────────────────┘   └───────────────────────┘
       │
       │   ┌───────────────────────────┐   ┌───────────────────────┐
       └───►  CloudinaryMediaItemBase  ├───►  CloudinaryMediaItem  │
           └───────────────────────────┘   └───────────────────────┘
"""

from .collection import (
    Collection,
    CollectionItemBase,
    ImageCollection,
    FileItemBase,
    ImageItemBase,
    SVGItemBase,
    FileItem,
    ImageItem,
    SVGItem,
)
from .fields import CollectionField, CollectionItem, FileField, SVGFileField, ImageField
from .file import UploadedFileBase, UploadedFile
from .svg import UploadedSVGFileBase, UploadedSVGFile
from .image import UploadedImageBase, UploadedImage

__all__ = [
    "UploadedFileBase",
    "UploadedFile",
    "UploadedSVGFileBase",
    "UploadedSVGFile",
    "UploadedImageBase",
    "UploadedImage",
    "FileField",
    "SVGFileField",
    "ImageField",
    "CollectionField",
    "CollectionItemBase",
    "CollectionItem",
    "Collection",
    "ImageCollection",
    "FileItemBase",
    "SVGItemBase",
    "ImageItemBase",
    "FileItem",
    "SVGItem",
    "ImageItem",
]
